<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:strip-space elements="*"/>
<xsl:output method="html" indent="yes" encoding="utf-8"/>

<xsl:template match="ORDER-FORM">
</xsl:template>

<xsl:template match="ORDER-FORM" mode="content">
	<input type="hidden" name="id">
		<xsl:attribute name="value"><xsl:value-of select="@ORDER-ID"/></xsl:attribute>
	</input>
	<table cellspacing="0" cellpadding="0" border="0" style="width:100%;">
		<tr style="vertical-align: top;">
			<td width="50%" style="padding-right: 10px;">
				<xsl:apply-templates select="GENERAL-CONTENT" mode="INFO"/>
				<div style="width: 0; height: 15px;"><span></span></div>
				<xsl:apply-templates select="COMMENT"/>
			</td>
			<td style="padding-left: 10px;">
				<xsl:apply-templates select="CONTACT-INFO"/>
				<xsl:apply-templates select="PAYMENT-METHOD"/>
			</td>
		</tr>
		<tr>
			<td colspan="2">
				<xsl:apply-templates select="GENERAL-CONTENT" mode="PRODUCTS"/>
			</td>
		</tr>
	</table>
	<xsl:call-template name="MODULE-MODAL-FORM-OK-CANCEL-BUTTONS"/>
</xsl:template>

<xsl:template match="ORDER-FORM" mode="initAfterBody">
	<xsl:call-template name="MODAL-FORM">
		<xsl:with-param name="formName">modalForm</xsl:with-param>
		<xsl:with-param name="formTitle" select="/SITEBUILDER-PAGE/LOCALE/FORM-TITLE"/>
		<xsl:with-param name="additionalFormStyle">width: 780px; height: 500px;</xsl:with-param>
		<xsl:with-param name="content" select="current()" />
		<xsl:with-param name="onCloseAction">sbNavigationObject.go();</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template match="GENERAL-CONTENT" mode="INFO">
	<table cellpadding="0" cellspacing="0" border="0" class="control-title-input">
		<tr>
			<td class="title-block">
				<xsl:apply-templates select="CONTROL[@NAME='orderId']" mode="label"/>
			</td>
			<td class="description-block" style="padding: 3px;"><xsl:value-of select="CONTROL[@NAME='orderId']"/></td>
		</tr>
		<tr>
			<td class="title-block">
				<xsl:apply-templates select="../CONTACT-INFO/CONTROL[@NAME='creationDate']" mode="label"/>
			</td>
			<td class="description-block" style="padding: 3px;"><xsl:value-of select="../CONTACT-INFO/CONTROL[@NAME='creationDate']"/></td>
		</tr>
		<tr>
			<td class="title-block">
				<xsl:apply-templates select="../CONTACT-INFO/CONTROL[@NAME='lastUpdatedDate']" mode="label"/>
			</td>
			<td class="description-block" style="padding: 3px;"><xsl:value-of select="../CONTACT-INFO/CONTROL[@NAME='lastUpdatedDate']"/></td>
		</tr>
		<tr>
			<td class="title-block">
				<xsl:apply-templates select="CONTROL[@NAME='status']" mode="label"/>
			</td>
			<td class="input-block"><xsl:apply-templates select="CONTROL[@NAME='status']" mode="control"/></td>
		</tr>
	</table>
	
</xsl:template>

<xsl:template match="GENERAL-CONTENT" mode="PRODUCTS">
	<style>
		.eshop-order-list { border: none; }
	</style>
	<div class="eshop-order-list" style="overflow:auto; width:100%;height:200px;">
		<xsl:apply-templates select="PAGED-LIST"/>
	</div>
</xsl:template>

<xsl:template match="GENERAL-CONTENT/PAGED-LIST/LIST/HEADER">
	<tr class="fixed">
		<th><div><xsl:value-of select="NAME"/></div></th>
		<th align="right"><div><xsl:value-of select="PRICE"/></div></th>
		<th align="center"><div><xsl:value-of select="QUANTITY"/></div></th>
		<th align="right"><div><xsl:value-of select="SUBTOTAL"/></div></th>
	</tr>
</xsl:template>

<xsl:template match="GENERAL-CONTENT/PAGED-LIST/LIST/ITEM">
	<xsl:variable name="class">
		<xsl:call-template name="LIST-ROW-CLASS">
	        	<xsl:with-param name="position"><xsl:value-of select="position()"/></xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<tr class="{$class}">
		<td>
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<tr>
					<td><xsl:value-of select="NAME"/></td>
				</tr>
				<xsl:if test="COLOR!=''">
				<tr>
					<td><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/PRODUCT-COLOR"/>: <b><xsl:value-of select="COLOR"/></b></td>
				</tr>
				</xsl:if>
				<xsl:if test="OPTIONS!=''">
				<tr>
					<td><xsl:apply-templates select="OPTIONS"/></td>
				</tr>
				</xsl:if>
			</table>
		</td>
		<xsl:call-template name="LIST-ROW-ITEM">
			<xsl:with-param name="align">right</xsl:with-param>
			<xsl:with-param name="title"><xsl:value-of select="PRICE"/></xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="LIST-ROW-ITEM">
			<xsl:with-param name="align">center</xsl:with-param>
			<xsl:with-param name="title"><xsl:value-of select="QUANTITY"/></xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="LIST-ROW-ITEM">
			<xsl:with-param name="align">right</xsl:with-param>
			<xsl:with-param name="title"><xsl:value-of select="SUBTOTAL"/></xsl:with-param>
		</xsl:call-template>
	</tr>
	<xsl:if test="position()=last()">
		<xsl:if test="ancestor::GENERAL-CONTENT/SHIPPING-INFO/@NAME!=''">
		<tr class="fixed">
			<th colspan="3">
				<div><xsl:value-of select="ancestor::GENERAL-CONTENT/SHIPPING-INFO/@NAME"/></div>
			</th>
			<th align="right">
				<div><xsl:value-of select="ancestor::GENERAL-CONTENT/SHIPPING-INFO/@COST"/></div>
			</th>
		</tr>
		</xsl:if>
		<tr class="fixed">
			<th colspan="3">
				<div><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/TOTAL"/>:</div>
			</th>
			<th align="right">
				<div><xsl:value-of select="ancestor::GENERAL-CONTENT/@TOTAL"/></div>
			</th>
		</tr>
	</xsl:if>
</xsl:template>

<xsl:template match="ITEM/OPTIONS/*">
	<xsl:value-of select="NAME"/>: <b><xsl:value-of select="VALUE"/></b>
	<xsl:if test="position()!=last()">,</xsl:if>&#160;
</xsl:template>


<xsl:template match="CONTACT-INFO">
	<fieldset>
		<legend><xsl:value-of select="@TITLE"/></legend>
		<div class="fieldset-block">
			<table width="100%">
				<tr><td><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/NAME"/>:</td><td><xsl:value-of select="FIRST-NAME"/>&#160;<xsl:value-of select="LAST-NAME"/></td></tr>
				<tr><td><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/EMAIL"/>:</td><td><xsl:value-of select="EMAIL"/></td></tr>
				<tr><td><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/PHONE"/>:</td><td><xsl:value-of select="PHONE-NUMBER"/></td></tr>
				<tr><td><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/COMPANY"/>:</td><td><xsl:value-of select="COMPANY"/></td></tr>
				<tr><td><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/ADDRESS"/>:</td><td>
					<xsl:value-of select="ADDRESS1"/>&#160;
					<xsl:value-of select="ADDRESS2"/>&#160;
					<xsl:value-of select="CITY"/>&#160;
					<xsl:value-of select="STATE"/>&#160;
					<xsl:value-of select="COUNTRY"/>&#160;
					<xsl:value-of select="ZIP"/>
				</td></tr>
			</table>
		</div>
	</fieldset>
</xsl:template>

<xsl:template match="COMMENT">
	<xsl:call-template name="LABEL" mode="label">
		<xsl:with-param name="title" select="/SITEBUILDER-PAGE/LOCALE/COMMENT-DESCRIPTION"/>
	</xsl:call-template><br/>
	<xsl:call-template name="TEXTAREA" mode="control">
		<xsl:with-param name="name">comment</xsl:with-param>
		<xsl:with-param name="value" select="."/>
	</xsl:call-template>
</xsl:template>

<xsl:template match="PAYMENT-METHOD">
	<fieldset>
		<legend><xsl:value-of select="@TITLE"/></legend>
		<div class="fieldset-block">
			<xsl:value-of select="."/>
		</div>
	</fieldset>
</xsl:template>

</xsl:stylesheet>