<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:strip-space elements="*"/>
	<xsl:output method="html" indent="yes" encoding="utf-8"/>

	<xsl:template match="PRODUCTS">
		<script language="javascript">
			function deleteProducts() {
				count = product_countSelectedCheckBoxes();
				if (count > 0) {
					if (confirm(count + ' <xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/SURE-TO-DELETE"/>')) {
						document.forms['SB_WizardForm'].action = '<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Eshop/Product/Delete';

						self.sbApplyChangesObject.registerForcedSaving();
						sbNavigationObject.go();
					}
				}
				else {
					alert('<xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/SELECT-FOR-DELETE"/>');
				}
			}
			function product_countSelectedCheckBoxes() {
				result = 0;
				var form = document.forms['SB_WizardForm'];
				for (var n = 0; n &lt; form.elements.length; n++) {
					if (form.elements[n].type == 'checkbox' &amp;&amp; form.elements[n].name=='product_objectIds[]') {
						if (form.elements[n].checked) {
							++result;
						}
					}
				}
				return result;
			}
			function product_setCheckboxStatus(status) {
				var form = document.forms['SB_WizardForm'];
				for (var n = 0; n &lt; form.elements.length; n++) {
					if (form.elements[n].type == 'checkbox' &amp;&amp; form.elements[n].name=='product_objectIds[]') {
						if (!form.elements[n].disabled) {
							form.elements[n].checked = status;
						}
					}
				}
			}
		</script>

		<xsl:apply-templates select="TOOLBAR" />
		<xsl:apply-templates select="PAGED-LIST"/>
	</xsl:template>

	<xsl:template match="PRODUCTS/PAGED-LIST/LIST/HEADER">
		<tr class="fixed">
			<th style="width:1%;">
				<div><input type="checkbox" name="globalCheck" onclick="product_setCheckboxStatus(this.checked);" class="check"/></div>
			</th>
			<th style="width:1%;"><div><xsl:value-of select="PICTURE"/></div></th>
			<th><div><xsl:value-of select="NAME"/></div></th>
			<th><div><xsl:value-of select="CATEGORIES"/></div></th>
			<th><div><xsl:value-of select="PRICE"/></div></th>
			<th><div><xsl:value-of select="INVENTORY"/></div></th>

			<xsl:if test="../../@IS-SEQUENCED=1">
				<th style="width:1%;"><div><span></span></div></th>
				<th style="width:1%;"><div><span></span></div></th>
			</xsl:if>

			<th style="width:1%;text-align:center;" scope="col">
				<div><xsl:value-of select="EDIT"/></div>
			</th>
		</tr>
	</xsl:template>

	<xsl:template match="PRODUCTS/PAGED-LIST/LIST/ITEM">
		<xsl:variable name="currentCategory" select="../../TOOLBAR/LIST-VIEW-STATES/@SELECTED"/>
		<xsl:variable name="class">
			<xsl:call-template name="LIST-ROW-CLASS">
		        <xsl:with-param name="position"><xsl:value-of select="position()"/></xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<tr class="{$class}">
			<td style="width:1%;">
				<input type="checkbox" name="product_objectIds[]" class="check">
					<xsl:attribute name="value"><xsl:value-of select="ID"/></xsl:attribute>
				</input>
			</td>
			<xsl:choose>
				<xsl:when test="not(IMAGE-ORIGINAL='')">
					<td>
						<a>
							<xsl:attribute name="href">#</xsl:attribute>
							<xsl:attribute name="onclick">
								<xsl:variable name="productImagePath">
									<xsl:value-of select="IMAGE-ORIGINAL/ITEM-0/FILE-NAME"/>
								</xsl:variable>
								<xsl:variable name="productImageWidth">
									<xsl:value-of select="IMAGE-ORIGINAL/ITEM-0/WIDTH"/>
								</xsl:variable>
								<xsl:variable name="productImageHeight">
									<xsl:value-of select="IMAGE-ORIGINAL/ITEM-0/HEIGHT"/>
								</xsl:variable>
								window.open('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Image?file=<xsl:value-of select="$productImagePath"/>', 'imagepreview', 'width=<xsl:value-of select="$productImageWidth+15"/>, height=<xsl:value-of select="$productImageHeight+5"/>, resizable=no, tolbar=no, status=no, scrollbars=no');return false;
							</xsl:attribute>
							<img style="border-width:0px;width:16px;height:16px" src="{$skinPath}/icons/prew.png"/>
						</a>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td></td>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="NAME"/></xsl:with-param>
			</xsl:call-template>

			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="CATEGORIES"/></xsl:with-param>
			</xsl:call-template>

			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="PRICE"/></xsl:with-param>
				<xsl:with-param name="wrap">nowrap</xsl:with-param>
			</xsl:call-template>

			<xsl:call-template name="LIST-ROW-ITEM">
				<xsl:with-param name="title"><xsl:value-of select="INVENTORY"/></xsl:with-param>
			</xsl:call-template>

			<xsl:if test="../../@IS-SEQUENCED=1">
				<td style="width:1%; text-align:center;">
					<xsl:if test="not(IS-FIRST=1)">
						<a>
							<xsl:attribute name="href">#</xsl:attribute>
							<xsl:attribute name="onclick">self.sbApplyChangesObject.registerForcedSaving();setWizardFormAction('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Eshop/Product/Up?id=<xsl:value-of select="ID"/>&amp;categoryId=<xsl:value-of select="$currentCategory"/>');sbNavigationObject.go();</xsl:attribute>
							<img style="border-width:0px;width:16px;height:16px" src="{$skinPath}/images/sequence-up.gif"/>
						</a>
					</xsl:if>
				</td>

				<td style="width:1%; text-align:center;">
					<xsl:if test="not(IS-LAST=1)">
						<a>
							<xsl:attribute name="href">#</xsl:attribute>
							<xsl:attribute name="onclick">self.sbApplyChangesObject.registerForcedSaving();setWizardFormAction('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Eshop/Product/Down?id=<xsl:value-of select="ID"/>&amp;categoryId=<xsl:value-of select="$currentCategory"/>');sbNavigationObject.go();</xsl:attribute>
							<img style="border-width:0px;width:16px;height:16px" src="{$skinPath}/images/sequence-down.gif"/>
						</a>
					</xsl:if>
				</td>
			</xsl:if>

			<td style="width:1%; text-align:center;">
				<a>
					<xsl:attribute name="href">#</xsl:attribute>
					<xsl:attribute name="onclick">
						self.sbApplyChangesObject.registerForcedSaving();
						sbNavigationObject.go('<xsl:value-of select="/SITEBUILDER-PAGE/VIEW-CONTENT/@ACTION"/>/Modules/Eshop/Product/Edit?id=<xsl:value-of select="ID"/>');
					</xsl:attribute>
					<xsl:attribute name="id"><xsl:value-of select="ID"/></xsl:attribute>
					<img style="border-width:0px;width:16px;height:16px" src="{$skinPath}/icons/editsiteinwizard.png"/>
				</a>
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>